@@ -5,11 +5,18 @@ use Module::Install::Base;
 
 use vars qw{$VERSION $ISCORE @ISA};
 BEGIN {
-	$VERSION = '0.65';
+	$VERSION = '0.69';
 	$ISCORE  = 1;
 	@ISA     = qw{Module::Install::Base};
 }
 
+
+
+
+
+#####################################################################
+# Previous API for Module::Install::Compoler
+
 sub c_files {
 	warn "c_files has been changed to cc_files to reduce confusion and keep all compiler commands as cc_";
 	shift()->cc_files(@_);
@@ -35,6 +42,25 @@ sub optimize_flags {
 	shift()->cc_optimize_flags(@_);
 }
 
+
+
+
+
+#####################################################################
+# Formerly Module::Install::AutoInstall
+
+sub AutoInstall {
+	die 'Module::Install::AutoInstall often breaks CPAN and has been deprecated';
+}
+
+sub auto_install {
+	die 'Module::Install::AutoInstall often breaks CPAN and has been deprecated';
+}
+
+sub auto_install_now {
+	die 'Module::Install::AutoInstall often breaks CPAN and has been deprecated';
+}
+
 1;
 
 __END__
@@ -90,7 +116,7 @@ consistency reasons.
 
 =head1 AUTHORS
 
-Adam Kennedy E<lt>cpan@ali.asE<gt>
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
@@ -98,7 +124,7 @@ L<Module::Install>
 
 =head1 COPYRIGHT
 
-Copyright 2006 Adam Kennedy. All rights reserved.
+Copyright 2006 Adam Kennedy.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
