@@ -13,7 +13,7 @@ use File::Spec ();
 
 use vars qw{$VERSION $ISCORE @ISA};
 BEGIN {
-	$VERSION = '0.65';
+	$VERSION = '0.69';
 	$ISCORE  = 1;
 	@ISA     = qw{Module::Install::Base};
 }
@@ -23,10 +23,40 @@ BEGIN {
 
 
 #####################################################################
-# CPAN Clients
+# CPAN Client
 
-# Are we currently running under the CPAN.pm client
+# What CPAN client are we running under
+sub cpan {
+	return 'cpanpm'   if cpanpm();
+	return 'cpanplus' if cpanplus();
+	return 'legacy'   if cpanlegacy();
+}
+
+# Are we running a legacy client
+sub cpanlegacy {
+	return 1 if cpanpm_legacy();
+	return 1 if cpanplus_legacy();
+	return '';
+}
+
+# Are we currently running under a CPAN.pm client (modern method)
+# Returns the version of the CPAN.pm client.
 sub cpanpm {
+	my $script = File::Spec->rel2abs($0);
+	return (
+		$ENV{PERL5_CPAN_IS_EXECUTING}
+		and
+		-f $script
+		and
+		$ENV{PERL5_CPAN_IS_EXECUTING} eq $script
+	)
+		? ($ENV{PERL5_CPAN_IS_VERSION} || -1)
+		: '';
+}
+
+# Are we currently running under the legacy CPAN client
+# This method is not reliable.
+sub cpanpm_legacy {
 	my $self = shift;
 
 	# Does the lock file exist?
@@ -70,18 +100,13 @@ sub cpanpm_config {
 # Are we currently running under the CPANPLUS client
 sub cpanplus {
 	my $script = File::Spec->rel2abs($0);
-	return !! (
+	return (
 		$ENV{PERL5_CPANPLUS_IS_EXECUTING}
 		and
 		-f $script
 		and
 		$ENV{PERL5_CPANPLUS_IS_EXECUTING} eq $script
-	);
-}
-
-# Are we (maybe) running under a legacy version of CPANPLUS
-sub cpanplus_legacy {
-	!! $ENV{CPANPLUS_IS_RUNNING};
+	) ? ($ENV{PERL5_CPANPLUS_IS_VERSION} || -1) : '';
 }
 
 # Is CPANPLUS actually installed
@@ -89,9 +114,9 @@ sub cpanplus_available {
 	$_[0]->can_use('CPANPLUS');
 }
 
-# Are we currently running under some automated testing system
-sub automated_testing {
-	!! $ENV{AUTOMATED_TESTING};
+# Are we (maybe) running under a legacy version of CPANPLUS
+sub cpanplus_legacy {
+	!! $ENV{CPANPLUS_IS_RUNNING};
 }
 
 
@@ -106,34 +131,30 @@ sub eumm {
 	!! ($0 =~ /Makefile.PL$/i);
 }
 
-# Are we targeting Module::Build (running as Build.PL)
-sub mb {
-	!! ($0 =~ /Build.PL$/i);
-}
-
-# Indicates the use of an ExtUtils::MakeMaker-only feature
-sub no_mb {
-	my $self = shift;
-	return 1 unless $self->mb;
-
-	# This installer is being run via a Build.PL but uses
-	# a feature that does not support Module::Build.
-	die "Build.PL tried to use a feature unsupported by Module::Build";
-}
-
 
 
 
 
 #####################################################################
-# User vs Author Context
+# Testing and Configuration Contexts
 
-sub user_mode {
-	1;
+# Are we in an interactive configuration environment
+sub interactive {
+	# Treat things interactively ONLY based on input
+	!! -t STDIN;
 }
 
-sub author_mode {
-	1;
+# Are we currently running under some sort of automated testing system
+sub automated_testing {
+	!! $ENV{AUTOMATED_TESTING};
+}
+
+sub user_context {
+	! $Module::Install::AUTHOR;
+}
+
+sub author_context {
+	!! $Module::Install::AUTHOR;
 }
 
 1;
